@@ -42,7 +42,9 @@ class VocabularyTerm(Segment):
             "Boolean": "A True or False value",
             "Boolean zen": "Using a boolean as a complete condition",
             "break statement": "Immediately end a loop",
+            "Case sensitive": "Treating uppercase and lowercase letters as distinct",
             "Chained comparison": "An expression with more than one comparison operator",  # noqa: E501
+            "Character": "A single letter, number, punctuation mark, or symbol represented as a string",  # noqa: E501
             "Class": "A blueprint for creating something specific",
             "Collection": "A grouping of information",
             "Collision": "When sprites touch or overlap",
@@ -65,6 +67,7 @@ class VocabularyTerm(Segment):
             "else clause": "When all prior conditions are false, runs a section of code as a last alternative",  # noqa: E501
             "Equal to": "Are the two values the same?",
             "Error": "When the computer encounters something unexpected in your code",  # noqa: E501
+            "Escape sequence": "Two or more sequential characters that have special meaning when combined",  # noqa: E501
             "Event": "A single action that occurs as a result of the user",  # noqa: E501
             "Exponentiation operator": "Multiplies a number by itself some number of times",  # noqa: E501
             "Expression": "A piece of code that produces a value",
@@ -79,6 +82,7 @@ class VocabularyTerm(Segment):
             "Header comment": 'A multi-line comment at the top of a program surrounded by `"""` marks',  # noqa: E501
             "Identity comparison": "Check whether two different variables refer to the same data",  # noqa: E501
             "if statement": "Runs a section of code when the condition is true",
+            "Immutable": "Unable to be changed after it is created",
             "Increment": "Increase a variable by an amount",
             "Index": "The zero-based position of an element in a collection",
             "Infinite loop": "A loop with a condition that will always be True",
@@ -98,6 +102,7 @@ class VocabularyTerm(Segment):
             "List equality comparison": "Check whether two lists contain all of the same elements in the same order",  # noqa: E501
             "List extend": "Copy all elements of one list to the end of another list",
             "List insert": "Add an element to a list at a position",
+            "List join": "Join the elements of a list into a string",
             "List remove": "Take an element out of a list by its value",
             "List repetition": "Create a new list from multiple copies of an existing list",  # noqa: E501
             "Literal": "A value you can literally see",
@@ -123,6 +128,7 @@ class VocabularyTerm(Segment):
             "Retrospective": "A formal review of the successes and failures of recent work",  # noqa: E501
             "Return value": "Information given back by a function",
             "Scope": "The set of work planned for a specific time period",  # noqa: E501
+            "Slice": "Create a new collection by copying a sequence of elements from an existing collection",  # noqa: E501
             "Sort": "Arrange the elements in a collection in ascending order",
             "Speed": "Attributes that control how fast and what direction an instance moves on screen",  # noqa: E501
             "Sprite": "An on-screen graphic based on an image",
@@ -135,6 +141,10 @@ class VocabularyTerm(Segment):
             "String": "A group of letters, symbols and/or numbers inside double quotation marks",  # noqa: E501
             "String concatenation": "Join two strings together with the + operator",
             "String multiplication": "Repeat a string a certain number of times with the * operator",  # noqa: E501
+            "String replace": "Create a new string by replacing all occurrences of a substring with a new substring",  # noqa: E501
+            "String separator": "A substring that is used to mark a division between other strings",  # noqa: E501
+            "String split": "Split a string into a list of substrings",
+            "Substring": "Zero or more sequential characters in a string",
             "Syntax": "The exact spelling, symbols, and order of code",
             "Text": "An on-screen graphic based on a string",
             "Then block": "A section of code that might get run",
@@ -144,6 +154,7 @@ class VocabularyTerm(Segment):
             "Variable": "A storage container for information",
             "Version": "A unique name or number for the state of a product at a particular time",  # noqa: E501
             "while loop": "Repeats a section of code until a condition is no longer True",  # noqa: E501
+            "Whitespace": "A character used for spacing, such as a space, tab, or newline",  # noqa: E501
             "Window": "A container for displaying graphics",
         }
 
@@ -161,7 +172,9 @@ class VocabularyTerm(Segment):
             "Boolean": "2.4.1",
             "Boolean zen": "2.4.2",
             "break statement": "3.2.1",
+            "Case sensitive": "4.5.2",
             "Chained comparison": "2.2.2",
+            "Character": "4.4.1",
             "Class": "3.3.1",
             "Collection": "4.1.1",
             "Collision": "3.6.2",
@@ -184,6 +197,7 @@ class VocabularyTerm(Segment):
             "else clause": "2.2.1",
             "Equal to": "2.1.1",
             "Error": "1.1.2",
+            "Escape sequence": "4.5.1",
             "Event": "3.6.1",
             "Exponentiation operator": "2.3.2",
             "Expression": "1.4.1",
@@ -198,6 +212,7 @@ class VocabularyTerm(Segment):
             "Header comment": "1.1.2",
             "Identity comparison": "4.3.2",
             "if statement": "2.1.1",
+            "Immutable": "4.4.1",
             "Increment": "1.4.1",
             "Index": "4.1.2",
             "Infinite loop": "3.1.1",
@@ -217,6 +232,7 @@ class VocabularyTerm(Segment):
             "List equality comparison": "4.3.2",
             "List extend": "4.2.2",
             "List insert": "4.2.2",
+            "List join": "4.5.1",
             "List remove": "4.2.2",
             "List repetition": "4.3.2",
             "Literal": "1.3.1",
@@ -242,6 +258,7 @@ class VocabularyTerm(Segment):
             "Retrospective": "2.pl3.1",
             "Return value": "1.4.2",
             "Scope": "2.pl3.1",
+            "Slice": "4.4.2",
             "Sort": "4.3.1",
             "Speed": "3.5.1",
             "Sprite": "3.4.1",
@@ -254,6 +271,10 @@ class VocabularyTerm(Segment):
             "String": "1.1.1",
             "String concatenation": "1.3.2",
             "String multiplication": "1.3.2",
+            "String replace": "4.5.2",
+            "String separator": "4.5.1",
+            "String split": "4.5.1",
+            "Substring": "4.4.1",
             "Syntax": "1.1.1",
             "Text": "3.4.2",
             "Then block": "2.2.1",
@@ -263,6 +284,7 @@ class VocabularyTerm(Segment):
             "Variable": "1.1.3",
             "Version": "2.pl3.1",
             "while loop": "3.1.1",
+            "Whitespace": "4.5.1",
             "Window": "3.4.1",
         }
 
